
# This file was generated by 'versioneer.py' (0.26) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2023-09-26T10:35:16+0300",
 "dirty": false,
 "error": null,
 "full-revisionid": "cb0c67a579b76bb0651c4fc54c18a0b7250a6515",
 "version": "3.21.0"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)



# Something is up with the pcluster constants
# from pcluster.constants import MAX_NUMBER_OF_QUEUES, MAX_NUMBER_OF_COMPUTE_RESOURCES_PER_CLUSTER
MAX_NUMBER_OF_QUEUES = 10
MAX_NUMBER_OF_COMPUTE_RESOURCES_PER_QUEUE = 5
MAX_NUMBER_OF_COMPUTE_RESOURCES = 50
MAX_NUMBER_OF_COMPUTE_RESOURCES_PER_CLUSTER = 50
